// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package aead_test

import (
	"testing"

	"github.com/tink-crypto/tink-go/v2/internal/aead"
)

func TestCheckPlaintextSize(t *testing.T) {
	for _, plaintextSize := range []uint64{16, 1 << 24} {
		if err := aead.CheckPlaintextSize(plaintextSize); err != nil {
			t.Errorf("aead.CheckPlaintextSize(%v) err = %v, want nil", plaintextSize, err)
		}
	}
	var largePlaintextSize uint64 = 1 << 60
	if err := aead.CheckPlaintextSize(largePlaintextSize); err == nil {
		t.Errorf("aead.CheckPlaintextSize(%v) err = nil, want error", largePlaintextSize)
	}
}
